| dtjoin_anti | R Documentation |
DT in a DT[i]-style join of data frame-like
objectsWrite (and optionally run) data.table code to return the anti-join of
DT (the rows of DT not joining with i) using a
generalisation of DT[i] syntax.
The functions fjoin_left_anti and fjoin_right_anti
provide a more conventional interface that is recommended over
dtjoin_anti for most users and cases.
dtjoin_anti(
.DT = NULL,
.i = NULL,
on,
match.na = FALSE,
mult = "all",
mult.DT = "all",
nomatch = NULL,
nomatch.DT = NULL,
select = NULL,
do = !(is.null(.DT) && is.null(.i)),
show = !do,
verbose = FALSE,
...
)
.DT, .i |
|
on |
A character vector of join predicates, e.g. |
match.na |
If |
mult |
(as in |
mult.DT |
Permitted for consistency with |
nomatch, nomatch.DT |
Permitted for consistency with |
select |
Character vector of columns of |
do |
Whether to execute the join. Default is |
show |
Whether to print the code for the join to the console. Default is
the opposite of |
verbose |
(passed to |
... |
Further arguments (for internal use). |
Details are as for dtjoin except for arguments controlling
the order and prefixing of output columns, which do not apply.
A data.frame, data.table, (grouped) tibble, sf,
or sf-tibble, or else NULL if do is FALSE. See
Details.
See the package-level documentation fjoin for related
functions.
# Mock joins
dtjoin_anti(on = "id")
dtjoin_anti(on = c("id", "date <= date"))
dtjoin_anti(on = c("id", "date <= date"), mult = "last")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.