Skip to contents

fjoin builds on data.table to provide fast, flexible joins on any data frames. It slots into tidyverse pipelines and general workflows in a single line, and provides NA-safe matching by default, on-the-fly column selection, flexible row-order preservation, multiple-match handling on both sides, and an indicator column for row origin.

Vignette

See the Get started guide on the package website.

Author

Maintainer: Toby Robertson trobx@proton.me